@@ -3,5 +3,7 @@ from .file import File
 from .func import Func
 from .lru import LRU
 from .buffer import Buffer
+from .sieve import Sieve
+from .lmdb import LMDB
 
-__version__ = '0.0.3'
+__version__ = '0.1.0'
