@@ -1,10 +1,12 @@
 from __future__ import absolute_import, division, print_function
 
-from collections import MutableMapping
+import errno
 import os
 
+from .common import ZictBase
 
-class File(MutableMapping):
+
+class File(ZictBase):
     """ Mutable Mapping interface to a directory
 
     Keys must be strings, values must be bytes
@@ -31,7 +33,9 @@ class File(MutableMapping):
         try:
             with open(os.path.join(self.directory, key), 'rb') as f:
                 result = f.read()
-        except (IOError, OSError):
+        except EnvironmentError as e:
+            if e.args[0] != errno.ENOENT:
+                raise
             raise KeyError(key)
         return result
 
@@ -46,13 +50,12 @@ class File(MutableMapping):
         return self.keys()
 
     def __delitem__(self, key):
-        os.remove(os.path.join(self.directory, key))
+        try:
+            os.remove(os.path.join(self.directory, key))
+        except EnvironmentError as e:
+            if e.args[0] != errno.ENOENT:
+                raise
+            raise KeyError(key)
 
     def __len__(self):
         return sum(1 for _ in self.keys())
-
-    def __enter__(self):
-        return self
-
-    def __exit__(self, type, value, traceback):
-        pass
