@@ -1,4 +1,8 @@
+from __future__ import absolute_import, division, print_function
+
 from zict import LRU
+from . import utils_test
+
 
 def test_simple():
     d = dict()
@@ -30,6 +34,17 @@ def test_simple():
     assert 'a' in repr(lru) and '5' in repr(lru)
 
 
+def test_mapping():
+    """
+    Test mapping interface for LRU().
+    """
+    d = {}
+    # 100 is more than the max length when running check_mapping()
+    lru = LRU(100, d)
+    utils_test.check_mapping(lru)
+    utils_test.check_closing(lru)
+
+
 def test_overwrite():
     d = dict()
     lru = LRU(2, d)
